@@ -469,6 +469,29 @@ class FolderListing(CommonBrowserView):
         final_res = sorted(res_list, key=lambda x: getattr(x, field, False))
         
         return Batch(final_res, results.size, start=results.start)
+    
+    def sort_by_alpha_with_transform(self, results, field):
+        """
+        Sorts results by field in alphabetic order
+        """
+        res_list = list(results)
+        final_res = sorted(res_list, key=lambda x:self.getTransform(getattr(x, field, False), x.portal_type).lower())
+        
+        return Batch(final_res, 1000, start=0)
+    
+    def getTransform(self, value, portal_type):
+        value = value.strip(' \t\n\r')
+        if isinstance(value, basestring) and portal_type == 'Media Person':
+            wordSplit = value.split(" ")
+            if len(wordSplit) < 2:
+                return value
+            else:
+                lastWord = wordSplit[len(wordSplit)-1]
+                firstWords = wordSplit[:-1]
+                final = "%s, %s"%(lastWord, " ".join(firstWords))
+                return final
+        else:
+            return value
   
 class EventListingView(FolderListing):
     """'
